#include "tao/ClientRequestInterceptor_Adapter_Factory.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_ClientRequestInterceptor_Adapter_Factory::~TAO_ClientRequestInterceptor_Adapter_Factory ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
